@@ -2,7 +2,7 @@ import logging
 from typing import Dict, List, Optional
 
 from aporia.core.errors import AporiaError
-from aporia.core.graphql_client import GraphQLClient
+from aporia.core.http_client import HttpClient
 from aporia.core.logging_utils import LOGGER_NAME
 from aporia.core.types.field import FieldCategory, FieldType
 
@@ -12,7 +12,7 @@ logger = logging.getLogger(LOGGER_NAME)
 
 
 async def run_create_model_version_query(
-    graphql_client: GraphQLClient,
+    http_client: HttpClient,
     model_id: str,
     model_version: str,
     model_type: str,
@@ -24,14 +24,14 @@ async def run_create_model_version_query(
     """Defines the schema for a specific model version.
 
     Args:
-        graphql_client (GraphQLClient): GraphQL client
-        model_id (str): Model ID
-        model_version (str): Model Version
-        model_type (str): Model type
-        features (Dict[str, str]): Feature fields
-        predictions (Dict[str, str]): Prediction fields
-        raw_inputs (Dict[str, str], optional): Raw input fields. Defaults to None.
-        metrics (Dict[str, str], optional): Prediction metric fields. Defaults to None.
+        http_client: Http client
+        model_id: Model ID
+        model_version: Model Version
+        model_type: Model type
+        features: Feature fields
+        predictions: Prediction fields
+        raw_inputs: Raw input fields.
+        metrics: Prediction metric fields.
     """
     query = """
         mutation CreateModelVersion(
@@ -67,7 +67,7 @@ async def run_create_model_version_query(
         "metrics": None if metrics is None else prepare_fields(metrics),
     }
 
-    result = await graphql_client.query_with_retries(query, variables)
+    result = await http_client.graphql(query, variables)
     for warning in result["createModelVersion"]["warnings"]:
         logger.warning(warning)
 
@@ -76,10 +76,10 @@ def prepare_fields(fields: Dict[str, str]) -> List[Dict[str, str]]:
     """Creates a list of Field GraphQL objects from a fields dict.
 
     Args:
-        fields (Dict[str, str]): Fields dict
+        fields: Fields dict
 
     Returns:
-        List[Dict[str, str]]: List of GraphQL Field objects.
+        List of GraphQL Field objects.
     """
     return [{"name": field_name, "type": field_type} for field_name, field_type in fields.items()]
 
@@ -93,10 +93,10 @@ def validate_fields_input(
     """Checks if the fields passed to create_model_version are valid.
 
     Args:
-        predictions (Dict[str, str]): Prediction fields
-        features (Dict[str, str]): Feature fields
-        raw_inputs (Dict[str, str], optional): Raw input fields. Defaults to None.
-        metrics (Dict[str, str], optional): Prediction metric fields. Defaults to None.
+        predictions: Prediction fields
+        features: Feature fields
+        raw_inputs: Raw input fields.
+        metrics: Prediction metric fields.
     """
     fields_to_validate = {FieldCategory.FEATURES: features, FieldCategory.PREDICTIONS: predictions}
 
