@@ -13,7 +13,7 @@ def _str_to_bool(value: str) -> bool:
 
 REQUIRED_SETTINGS = [
     ConfigVar("token", "APORIA_TOKEN", None, str),
-    ConfigVar("host", "APORIA_HOST", "cloud.aporia.com", str),
+    ConfigVar("host", "APORIA_HOST", "app.aporia.com", str),
     ConfigVar("environment", "APORIA_ENVIRONMENT", None, str),
 ]
 OPTIONAL_SETTINGS = [
